@@ -4,11 +4,12 @@ from .action import ActionMixin
 from .allow_tags import AllowTagsMixin
 from .boolean_field import BooleanFieldMixin
 from .enable_copy import EnableCopyMixin
+from .file_field import FileFieldMixin
 from .help_text import FieldHelpTextMixin
 from .implicit_hidden import HiddenFieldMixin
 from .implicit_natural_date import DateFieldMixin, DateTimeFieldMixin, TimeFieldMixin
 from .null_choice import NullChoiceMixin
-from .null_integer import NullIntegerMixin
+from .null_value import NullValueMixin
 from .password_field import PasswordFieldMixin
 from .related_field_ajax import RelatedFieldAJAXMixin
 from .render import DisplayMode, RenderMixin
